diff png.c @ 4515:a2b14c6fccfd libavcodec

consistency renaming: rgba32 --> rgb32
author diego
date Mon, 12 Feb 2007 23:07:17 +0000
parents ce643a22f049
children 6166fbf375cc
line wrap: on
line diff
--- a/png.c	Mon Feb 12 10:05:19 2007 +0000
+++ b/png.c	Mon Feb 12 23:07:17 2007 +0000
@@ -344,7 +344,7 @@
 }
 
 #ifdef CONFIG_ENCODERS
-static void convert_from_rgba32(uint8_t *dst, const uint8_t *src, int width)
+static void convert_from_rgb32(uint8_t *dst, const uint8_t *src, int width)
 {
     uint8_t *d;
     int j;
@@ -363,7 +363,7 @@
 #endif
 
 #ifdef CONFIG_DECODERS
-static void convert_to_rgba32(uint8_t *dst, const uint8_t *src, int width)
+static void convert_to_rgb32(uint8_t *dst, const uint8_t *src, int width)
 {
     int j;
     unsigned int r, g, b, a;
@@ -392,7 +392,7 @@
             png_filter_row(s->tmp_row, s->crow_buf[0], s->crow_buf + 1,
                            s->last_row, s->row_size, s->bpp);
             memcpy(s->last_row, s->tmp_row, s->row_size);
-            convert_to_rgba32(ptr, s->tmp_row, s->width);
+            convert_to_rgb32(ptr, s->tmp_row, s->width);
         } else {
             /* in normal case, we avoid one copy */
             if (s->y == 0)
@@ -422,7 +422,7 @@
                 got_line = 1;
             }
             if ((png_pass_dsp_ymask[s->pass] << (s->y & 7)) & 0x80) {
                 /* NOTE: rgba32 is handled directly in png_put_interlaced_row */
                 png_put_interlaced_row(ptr, s->width, s->bits_per_pixel, s->pass,
                                        s->color_type, s->last_row);
             }
@@ -882,7 +882,7 @@
                     if ((png_pass_ymask[pass] << (y & 7)) & 0x80) {
                         ptr = p->data[0] + y * p->linesize[0];
                         if (color_type == PNG_COLOR_TYPE_RGB_ALPHA) {
-                            convert_from_rgba32(tmp_buf, ptr, avctx->width);
+                            convert_from_rgb32(tmp_buf, ptr, avctx->width);
                             ptr1 = tmp_buf;
                         } else {
                             ptr1 = ptr;
@@ -900,7 +900,7 @@
         for(y = 0; y < avctx->height; y++) {
             ptr = p->data[0] + y * p->linesize[0];
             if (color_type == PNG_COLOR_TYPE_RGB_ALPHA)
-                convert_from_rgba32(crow_buf + 1, ptr, avctx->width);
+                convert_from_rgb32(crow_buf + 1, ptr, avctx->width);
             else
                 memcpy(crow_buf + 1, ptr, row_size);
             crow_buf[0] = PNG_FILTER_VALUE_NONE;
@@ -422,7 +422,7 @@
             }
             if ((png_pass_dsp_ymask[s->pass] << (s->y & 7)) & 0x80) {
-                /* NOTE: rgba32 is handled directly in png_put_interlaced_row */
+                /* NOTE: RGB32 is handled directly in png_put_interlaced_row */
                 png_put_interlaced_row(ptr, s->width, s->bits_per_pixel, s->pass,
                                        s->color_type, s->last_row);